@@ -7,10 +7,10 @@ from .asserts import (  # noqa
     assert_nullable
 )
 from .exceptions import ImproperlyConfigured  # noqa
-from .expression_parser import ExpressionParser  # noqa
 from .expressions import Asterisk, row_to_json  # noqa
 from .functions import (  # noqa
     analyze,
+    cast_if,
     create_database,
     create_mock_engine,
     database_exists,
@@ -22,6 +22,7 @@ from .functions import (  # noqa
     get_column_key,
     get_columns,
     get_declarative_base,
+    get_fk_constraint_for_columns,
     get_hybrid_properties,
     get_mapper,
     get_primary_keys,
@@ -92,4 +93,4 @@ from .types import (  # noqa
     WeekDaysType
 )
 
-__version__ = '0.30.13'
+__version__ = '0.32.2'
