@@ -7,8 +7,8 @@ import sqlalchemy as sa
 from sqlalchemy.engine.url import make_url
 from sqlalchemy.exc import OperationalError, ProgrammingError
 
-from sqlalchemy_utils.expressions import explain_analyze
-
+from ..expressions import explain_analyze
+from ..utils import starts_with
 from .orm import quote
 
 
@@ -164,7 +164,8 @@ def json_sql(value, scalars_to_json=True):
     """
     scalar_convert = sa.text
     if scalars_to_json:
-        scalar_convert = lambda a: sa.func.to_json(sa.text(a))
+        def scalar_convert(a):
+            return sa.func.to_json(sa.text(a))
 
     if isinstance(value, collections.Mapping):
         return sa.func.json_build_object(
@@ -187,16 +188,23 @@ def json_sql(value, scalars_to_json=True):
     return value
 
 
-def has_index(column):
+def has_index(column_or_constraint):
     """
-    Return whether or not given column has an index. A column has an index if
-    it has a single column index or it is the first column in compound column
-    index.
+    Return whether or not given column or the columns of given foreign key
+    constraint have an index. A column has an index if it has a single column
+    index or it is the first column in compound column index.
 
-    :param column: SQLAlchemy Column object
+    A foreign key constraint has an index if the constraint columns are the
+    first columns in compound column index.
+
+    :param column_or_constraint:
+        SQLAlchemy Column object or SA ForeignKeyConstraint object
 
     .. versionadded: 0.26.2
 
+    .. versionchanged: 0.30.18
+        Added support for foreign key constaints.
+
     ::
 
         from sqlalchemy_utils import has_index
@@ -240,33 +248,81 @@ def has_index(column):
 
         has_index(table.c.locale)   # False
         has_index(table.c.id)       # True
+
+
+    This function supports foreign key constraints as well:
+
+
+        class User(Base):
+            __tablename__ = 'user'
+            first_name = sa.Column(sa.Unicode(255), primary_key=True)
+            last_name = sa.Column(sa.Unicode(255), primary_key=True)
+
+        class Article(Base):
+            __tablename__ = 'article'
+            id = sa.Column(sa.Integer, primary_key=True)
+            author_first_name = sa.Column(sa.Unicode(255))
+            author_last_name = sa.Column(sa.Unicode(255))
+            __table_args__ = (
+                sa.ForeignKeyConstraint(
+                    [author_first_name, author_last_name],
+                    [User.first_name, User.last_name]
+                ),
+                sa.Index(
+                    'my_index',
+                    author_first_name,
+                    author_last_name
+                )
+            )
+
+        table = Article.__table__
+        constraint = list(table.foreign_keys)[0].constraint
+
+        has_index(constraint)  # True
     """
-    table = column.table
+    table = column_or_constraint.table
     if not isinstance(table, sa.Table):
         raise TypeError(
             'Only columns belonging to Table objects are supported. Given '
             'column belongs to %r.' % table
         )
+    primary_keys = table.primary_key.columns.values()
+    if isinstance(column_or_constraint, sa.ForeignKeyConstraint):
+        columns = list(column_or_constraint.columns.values())
+    else:
+        columns = [column_or_constraint]
+
     return (
-        column is table.primary_key.columns.values()[0]
-        or
+        (primary_keys and starts_with(primary_keys, columns)) or
         any(
-            index.columns.values()[0] is column
+            starts_with(index.columns.values(), columns)
             for index in table.indexes
         )
     )
 
 
-def has_unique_index(column):
+def has_unique_index(column_or_constraint):
     """
-    Return whether or not given column has a unique index. A column has a
-    unique index if it has a single column primary key index or it has a
-    single column UniqueConstraint.
+    Return whether or not given column or given foreign key constraint has a
+    unique index.
+
+    A column has a unique index if it has a single column primary key index or
+    it has a single column UniqueConstraint.
+
+    A foreign key constraint has a unique index if the columns of the
+    constraint are the same as the columns of table primary key or the coluns
+    of any unique index or any unique constraint of the given table.
 
     :param column: SQLAlchemy Column object
 
     .. versionadded: 0.27.1
 
+    .. versionchanged: 0.30.18
+        Added support for foreign key constaints.
+
+        Fixed support for unique indexes (previously only worked for unique
+        constraints)
+
     ::
 
         from sqlalchemy_utils import has_unique_index
@@ -288,31 +344,67 @@ def has_unique_index(column):
         has_unique_index(table.c.id)           # True
 
 
+    This function supports foreign key constraints as well:
+
+
+        class User(Base):
+            __tablename__ = 'user'
+            first_name = sa.Column(sa.Unicode(255), primary_key=True)
+            last_name = sa.Column(sa.Unicode(255), primary_key=True)
+
+        class Article(Base):
+            __tablename__ = 'article'
+            id = sa.Column(sa.Integer, primary_key=True)
+            author_first_name = sa.Column(sa.Unicode(255))
+            author_last_name = sa.Column(sa.Unicode(255))
+            __table_args__ = (
+                sa.ForeignKeyConstraint(
+                    [author_first_name, author_last_name],
+                    [User.first_name, User.last_name]
+                ),
+                sa.Index(
+                    'my_index',
+                    author_first_name,
+                    author_last_name,
+                    unique=True
+                )
+            )
+
+        table = Article.__table__
+        constraint = list(table.foreign_keys)[0].constraint
+
+        has_unique_index(constraint)  # True
+
+
     :raises TypeError: if given column does not belong to a Table object
     """
-    table = column.table
+    table = column_or_constraint.table
     if not isinstance(table, sa.Table):
         raise TypeError(
             'Only columns belonging to Table objects are supported. Given '
             'column belongs to %r.' % table
         )
-    pks = table.primary_key.columns
+    primary_keys = list(table.primary_key.columns.values())
+    if isinstance(column_or_constraint, sa.ForeignKeyConstraint):
+        columns = list(column_or_constraint.columns.values())
+    else:
+        columns = [column_or_constraint]
+
     return (
-        (column is pks.values()[0] and len(pks) == 1)
-        or
+        (columns == primary_keys) or
         any(
-            match_columns(constraint.columns.values()[0], column) and
-            len(constraint.columns) == 1
-            for constraint in column.table.constraints
+            columns == list(constraint.columns.values())
+            for constraint in table.constraints
             if isinstance(constraint, sa.sql.schema.UniqueConstraint)
+        ) or
+        any(
+            columns == list(index.columns.values())
+            for index in table.indexes
+            if index.unique
         )
     )
 
 
-def match_columns(column, column2):
-    return column.table is column2.table and column.name == column2.name
-
-
 def is_auto_assigned_date_column(column):
     """
     Returns whether or not given SQLAlchemy Column object's is auto assigned
@@ -324,8 +416,7 @@ def is_auto_assigned_date_column(column):
         (
             isinstance(column.type, sa.DateTime) or
             isinstance(column.type, sa.Date)
-        )
-        and
+        ) and
         (
             column.default or
             column.server_default or
@@ -375,7 +466,12 @@ def database_exists(url):
         return bool(engine.execute(text).scalar())
 
     elif engine.dialect.name == 'sqlite':
-        return database == ':memory:' or os.path.exists(database)
+        if database:
+            return database == ':memory:' or os.path.exists(database)
+        else:
+            # The default SQLAlchemy database is in memory,
+            # and :memory is not required, thus we should support that use-case
+            return True
 
     else:
         text = 'SELECT 1'
@@ -447,7 +543,8 @@ def create_database(url, encoding='utf8', template=None):
         engine.execute(text)
 
     elif engine.dialect.name == 'sqlite' and database != ':memory:':
-        open(database, 'w').close()
+        if database:
+            open(database, 'w').close()
 
     else:
         text = 'CREATE DATABASE {0}'.format(quote(engine, database))
@@ -478,8 +575,9 @@ def drop_database(url):
 
     engine = sa.create_engine(url)
 
-    if engine.dialect.name == 'sqlite' and url.database != ':memory:':
-        os.remove(url.database)
+    if engine.dialect.name == 'sqlite' and database != ':memory:':
+        if database:
+            os.remove(database)
 
     elif engine.dialect.name == 'postgresql' and engine.driver == 'psycopg2':
         from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
